Method: Overcommit::Hook::Base#flags

Defined in:
lib/overcommit/hook/base.rb

#flagsArray<String>

Return command line flags to be passed to the command.

This excludes the list of files, as that must be handled by the hook itself.

The intention here is to provide flexibility for when a tool removes/renames its flags. Rather than wait for Overcommit to update the flags it uses, you can update your configuration to use the new flags right away without being blocked.

Also note that any flags containing dynamic content must be passed in the hook’s #run method.

Returns:

  • (Array<String>)


153
154
155
# File 'lib/overcommit/hook/base.rb', line 153

def flags
  Array(@config['flags'])
end