Class: Overcommit::Hook::PreCommit::OxLint
- Defined in:
- lib/overcommit/hook/pre_commit/ox_lint.rb
Overview
Runs ‘oxlint` against any modified JavaScript files.
Protip: if you have an npm script set up to run oxlint, you can configure this hook to run oxlint via your npm script by using the ‘command` option in your .overcommit.yml file. This can be useful if you have some oxlint configuration built into your npm script that you don’t want to repeat somewhere else. Example:
OxLint:
required_executable: 'npm'
enabled: true
command: ['npm', 'run', 'lint', '--', '--format=unix']
Note: This hook supports only unix format.
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
#applicable_files, #command, #description, #enabled?, #excluded?, #execute, #execute_in_background, #flags, #in_path?, #included_files, #initialize, #name, #parallelize?, #processors, #quiet?, #required?, #required_executable, #required_libraries, #run?, #run_and_transform, #skip?
Constructor Details
This class inherits a constructor from Overcommit::Hook::Base
Instance Method Details
#run ⇒ Object
21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/overcommit/hook/pre_commit/ox_lint.rb', line 21 def run oxlint_regex = %r{^(?:file://)?(?<file>[^:]+):(?<line>\d+):\d+:.*?(?<type>Error|Warning)} result = execute(command, args: applicable_files) output = result.stdout.chomp = output.split("\n").grep(oxlint_regex) return [:fail, result.stderr] if .empty? && !result.success? return :pass if result.success? && output.empty? # example message: # file://test.js:5:1: `debugger` statement is not allowed [Error/eslint(no-debugger)] (, oxlint_regex, lambda { |type| type.downcase.to_sym }) end |