Method: Overcommit::HookContext::Base#execute_hook

Defined in:
lib/overcommit/hook_context/base.rb

#execute_hook(command) ⇒ Object

Executes a command as if it were a regular git hook, passing all command-line arguments and the standard input stream.

This is intended to be used by ad hoc hooks so developers can link up their existing git hooks with Overcommit.



32
33
34
# File 'lib/overcommit/hook_context/base.rb', line 32

def execute_hook(command)
  Overcommit::Utils.execute(command, args: @args, input: input_string)
end