Method: Overcommit::Utils.execute
- Defined in:
- lib/overcommit/utils.rb
.execute(args) ⇒ Object
Wrap external subshell calls. This is necessary in order to allow Overcommit to call other Ruby executables without requiring that they be specified in Overcommit’s Gemfile–a nasty consequence of using ‘bundle exec overcommit` while developing locally.
65 66 67 68 69 |
# File 'lib/overcommit/utils.rb', line 65 def execute(args) with_environment 'RUBYOPT' => nil do Subprocess.spawn(args) end end |